@@ -1,165 +1,14 @@
 package Mojolicious::Plugin::LinkEmbedder;
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder - Convert a URL to embedded content
-
-=head1 VERSION
-
-0.2301
-
-=head1 DESCRIPTION
-
-This module can transform a URL to an iframe, image or other embeddable
-content.
-
-=head1 SYNOPSIS
-
-=head2 Simple version
-
-  use Mojolicious::Lite;
-  plugin LinkEmbedder => { route => '/embed' };
-
-=head2 Full control
-
-  plugin 'LinkEmbedder';
-
-  get '/embed' => sub {
-    my $c = shift;
-
-    $c->delay(
-      sub {
-        my ($delay) = @_;
-        $c->embed_link($c->param('url'), $delay->begin);
-      },
-      sub {
-        my ($delay, $link) = @_;
-
-        $c->respond_to(
-          json => {
-            json => {
-              media_id => $link->media_id,
-              url => $link->url->to_string,
-            },
-          },
-          any => { text => $link->to_embed }
-        );
-      }
-    );
-  };
-
-=head2 Example with caching
-
-  plugin 'LinkEmbedder';
-
-  get '/embed' => sub {
-    my $c = shift;
-    my $url = $c->param('url');
-    my $cached;
-
-    $c->delay(
-      sub {
-        my ($delay) = @_;
-        return $delay->pass($cached) if $cached = $c->cache->get($url);
-        return $c->embed_link($c->param('url'), $delay->begin);
-      },
-      sub {
-        my ($delay, $link) = @_;
-
-        $link = $link->TO_JSON if UNIVERSAL::can($link, 'TO_JSON');
-        $c->cache->set($url => $link);
-
-        $c->respond_to(
-          json => {
-            json => {
-              media_id => $link->{media_id},
-              url => $link->{url},
-            },
-          },
-          any => { text => $link->{html} }
-        );
-      }
-    );
-  };
-
-=head1 SUPPORTED LINKS
-
-=over 4
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Xkcd>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Music::Spotify>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Blip>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Collegehumor>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dagbladet>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Github>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Ix>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Metacpan>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastebin>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastie>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::PasteScsysCoUk>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter>
-
-=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis>
-
-=back
-
-=cut
-
 use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::JSON;
 use Mojo::UserAgent;
 use Mojolicious::Plugin::LinkEmbedder::Link;
 use constant DEBUG => $ENV{MOJO_LINKEMBEDDER_DEBUG} || 0;
 
-our $VERSION = '0.2301';
+our $VERSION = '0.24';
 
 has _ua => sub { Mojo::UserAgent->new(max_redirects => 3) };
 
-=head1 METHODS
-
-=head2 embed_link
-
-See L</SYNOPSIS>.
-
-=cut
-
 sub embed_link {
   my ($self, $c, $url, $cb) = @_;
 
@@ -250,26 +99,6 @@ sub _new_link_object {
   return $class;
 }
 
-=head2 register
-
-  $app->plugin('LinkEmbedder' => \%config);
-
-Will register the L</embed_link> helper which creates new objects from
-L<Mojolicious::Plugin::LinkEmbedder::Default>. C<%config> is optional but can
-contain:
-
-=over 4
-
-=item * route => $str|$obj
-
-Use this if you want to have the default handler to do link embedding.
-The default handler is shown in L</SYNOPSIS>. C<$str> is just a path,
-while C<$obj> is a L<Mojolicious::Routes::Route> object.
-
-=back
-
-=cut
-
 sub register {
   my ($self, $app, $config) = @_;
 
@@ -278,11 +107,11 @@ sub register {
     '2play'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play',
     'beta.dbtv'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
     'dbtv'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
-    'blip'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Blip',
     'collegehumor'   => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Collegehumor',
     'gist.github'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub',
     'github'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Github',
     'html'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML',
+    'instagram'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Instagram',
     'image'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Image',
     'imgur'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur',
     'ix'             => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Ix',
@@ -353,6 +182,174 @@ sub _add_action {
   );
 }
 
+1;
+
+=encoding utf8
+
+=head1 NAME
+
+Mojolicious::Plugin::LinkEmbedder - Convert a URL to embedded content
+
+=head1 VERSION
+
+0.24
+
+=head1 DESCRIPTION
+
+This module can transform a URL to an iframe, image or other embeddable
+content.
+
+=head1 SYNOPSIS
+
+=head2 Simple version
+
+  use Mojolicious::Lite;
+  plugin LinkEmbedder => { route => '/embed' };
+
+=head2 Full control
+
+  plugin 'LinkEmbedder';
+
+  get '/embed' => sub {
+    my $c = shift;
+
+    $c->delay(
+      sub {
+        my ($delay) = @_;
+        $c->embed_link($c->param('url'), $delay->begin);
+      },
+      sub {
+        my ($delay, $link) = @_;
+
+        $c->respond_to(
+          json => {
+            json => {
+              media_id => $link->media_id,
+              url => $link->url->to_string,
+            },
+          },
+          any => { text => $link->to_embed }
+        );
+      }
+    );
+  };
+
+=head2 Example with caching
+
+  plugin 'LinkEmbedder';
+
+  get '/embed' => sub {
+    my $c = shift;
+    my $url = $c->param('url');
+    my $cached;
+
+    $c->delay(
+      sub {
+        my ($delay) = @_;
+        return $delay->pass($cached) if $cached = $c->cache->get($url);
+        return $c->embed_link($c->param('url'), $delay->begin);
+      },
+      sub {
+        my ($delay, $link) = @_;
+
+        $link = $link->TO_JSON if UNIVERSAL::can($link, 'TO_JSON');
+        $c->cache->set($url => $link);
+
+        $c->respond_to(
+          json => {
+            json => {
+              media_id => $link->{media_id},
+              url => $link->{url},
+            },
+          },
+          any => { text => $link->{html} }
+        );
+      }
+    );
+  };
+
+=head1 SUPPORTED LINKS
+
+=over 4
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Instagram>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Image::Xkcd>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Music::Spotify>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Collegehumor>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dagbladet>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Github>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Ix>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Metacpan>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastebin>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastie>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::PasteScsysCoUk>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis>
+
+=back
+
+=head1 METHODS
+
+=head2 embed_link
+
+See L</SYNOPSIS>.
+
+=head2 register
+
+  $app->plugin('LinkEmbedder' => \%config);
+
+Will register the L</embed_link> helper which creates new objects from
+L<Mojolicious::Plugin::LinkEmbedder::Default>. C<%config> is optional but can
+contain:
+
+=over 4
+
+=item * route => $str|$obj
+
+Use this if you want to have the default handler to do link embedding.
+The default handler is shown in L</SYNOPSIS>. C<$str> is just a path,
+while C<$obj> is a L<Mojolicious::Routes::Route> object.
+
+=back
+
 =head1 DISCLAIMER
 
 This module might embed javascript from 3rd party services.
@@ -378,5 +375,3 @@ Joel Berger, jberger@cpan.org
 Marcus Ramberg - C<mramberg@cpan.org>
 
 =cut
-
-1;
