@@ -1,23 +1,6 @@
 package Mojolicious::Plugin::LinkEmbedder::Link::Text::Github;
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder::Link::Text::Github - github.com link
-
-=head1 DESCRIPTION
-
-This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML>.
-
-=cut
-
 use Mojo::Base 'Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML';
 
-=head1 ATTRIBUTES
-
-=head2 provider_name
-
-=cut
-
 sub provider_name {'Github'}
 
 sub _learn_from_dom {
@@ -38,7 +21,7 @@ sub _learn_from_dom {
   if ($self->url->path =~ m!/commit!) {
     $self->image($e->{src}) if $e = $dom->at('img.avatar') and $e->{src};
     $self->title($e->all_text)       if $e = $dom->at('.commit-title');
-    $self->description($e->all_text) if $e = $dom->at('.commit-meta .authorship');
+    $self->description($e->all_text) if $e = $dom->at('.commit-author-section');
   }
   elsif ($self->url->path =~ m!/(?:issue|pull)!) {
     $self->image($e->{src}) if $e = $dom->at('img.timeline-comment-avatar') and $e->{src};
@@ -47,10 +30,24 @@ sub _learn_from_dom {
   }
 }
 
+1;
+
+=encoding utf8
+
+=head1 NAME
+
+Mojolicious::Plugin::LinkEmbedder::Link::Text::Github - github.com link
+
+=head1 DESCRIPTION
+
+This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML>.
+
+=head1 ATTRIBUTES
+
+=head2 provider_name
+
 =head1 AUTHOR
 
 Jan Henning Thorsen
 
 =cut
-
-1;
