@@ -1,26 +1,5 @@
 package Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn;
-
-=head1 NAME
-
-Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn - vimeo.com video
-
-=head1 DESCRIPTION
-
-This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Video>.
-
-=cut
-
-use Mojo::Base 'Mojolicious::Plugin::LinkEmbedder::Link::Video';
-
-=head1 ATTRIBUTES
-
-=head2 media_id
-
-Returns the room name from the url L</url>.
-
-=head2 provider_name
-
-=cut
+use Mojo::Base 'Mojolicious::Plugin::LinkEmbedder::Link';
 
 has media_id => sub {
   my $self = shift;
@@ -31,12 +10,6 @@ has media_id => sub {
 
 sub provider_name {'appear.in'}
 
-=head1 METHODS
-
-=head2 learn
-
-=cut
-
 sub learn {
   my ($self, $c, $cb) = @_;
 
@@ -44,12 +17,6 @@ sub learn {
   return $self->SUPER::learn($c, $cb);
 }
 
-=head2 to_embed
-
-Returns the HTML code for an iframe embedding this movie.
-
-=cut
-
 sub to_embed {
   my $self     = shift;
   my $media_id = $self->media_id or return $self->SUPER::to_embed;
@@ -63,10 +30,36 @@ sub to_embed {
   );
 }
 
+1;
+
+=encoding utf8
+
+=head1 NAME
+
+Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn - vimeo.com video
+
+=head1 DESCRIPTION
+
+This class inherit from L<Mojolicious::Plugin::LinkEmbedder::Link::Video>.
+
+=head1 ATTRIBUTES
+
+=head2 media_id
+
+Returns the room name from the url L</url>.
+
+=head2 provider_name
+
+=head1 METHODS
+
+=head2 learn
+
+=head2 to_embed
+
+Returns the HTML code for an iframe embedding this movie.
+
 =head1 AUTHOR
 
 Marcus Ramberg
 
 =cut
-
-1;
